.. _contributing:

===================================
Contributing to python-ironicclient
===================================

If you're interested in contributing to the python-ironicclient project,
the following will help get you started.

#openstack-ironic on OFTC IRC Network
-------------------------------------
There is a very active chat channel at irc://irc.oftc.net/#openstack-ironic.
This is usually the best place to ask questions and find your way around.
IRC stands for Internet Relay Chat and it is a way to chat online in real
time. You can ask a question and come back later to read the answer in the
log files. Logs for the #openstack-ironic IRC channel are stored at
http://eavesdrop.openstack.org/irclogs/%23openstack-ironic/.

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the python-ironicclient project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * https://docs.openstack.org/infra/manual/developers.html
   * https://wiki.openstack.org/wiki/CLA

Project Hosting Details
-----------------------

Bug tracker
    https://storyboard.openstack.org/#!/project/959

Mailing list (prefix subjects with ``[ironic]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

Code Hosting
    https://opendev.org/openstack/python-ironicclient

Code Review
    https://review.opendev.org/#/q/status:open+project:openstack/python-ironicclient,n,z

